<?xml version="1.0" ?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="text" />
  <xsl:param name="arch" />
  <xsl:param name="dir" />

  <xsl:template match="/">
    <xsl:apply-templates select="repoml" />
  </xsl:template>

  <xsl:template match="repoml">
    <xsl:variable name="globaloptions" select="options" />
    <xsl:for-each select="repofile[repo/archs/arch/@value=$arch]">
      <xsl:variable name="repofilename"><xsl:copy-of select="concat(@name, '.repo')" /></xsl:variable>
      <xsl:variable name="dirname">
        <xsl:if test="$dir!=''">
          <xsl:value-of select="$dir" />
          <xsl:text>/</xsl:text>
        </xsl:if>
      </xsl:variable>
      <xsl:document href="{$dirname}{$repofilename}" method="text">
        <xsl:for-each select="repo[archs/arch/@value=$arch]">
          <xsl:if test="position()>1">
            <xsl:text>
</xsl:text>
          </xsl:if>
          <xsl:apply-templates select=".">
            <xsl:with-param name="globaloptions" select="$globaloptions" />
          </xsl:apply-templates>
        </xsl:for-each>
        <xsl:text>
</xsl:text>
      </xsl:document>
    </xsl:for-each>
  </xsl:template>

  <xsl:template match="repo">
    <xsl:param name="globaloptions" />
    <xsl:value-of select="concat('[', @name, ']')" />
    <xsl:text>
</xsl:text>
    <xsl:text>name=</xsl:text>
    <xsl:value-of select="description" />
    <xsl:text>
</xsl:text>
    <xsl:variable name="localoptions" select="gpgkey|enabled|exclude|retries|timeout|baseurl|mirrorlist" />
    <xsl:variable name="archoptions" select="archs/arch[@value=$arch]" />
    <xsl:call-template name="printlocations">
      <xsl:with-param name="archlocation" select="$archoptions" />
      <xsl:with-param name="location" select="$localoptions" />
    </xsl:call-template>
    <xsl:call-template name="printgpgkey">
      <xsl:with-param name="archgpgkey" select="$archoptions/gpgkey" />
      <xsl:with-param name="gpgkey" select="$localoptions[name()='gpgkey']" />
    </xsl:call-template>
    <xsl:call-template name="printoptions">
      <xsl:with-param name="archoptions" select="$archoptions" />
      <xsl:with-param name="globaloptions" select="$globaloptions" />
      <xsl:with-param name="localoptions" select="$localoptions" />
      <xsl:with-param name="tag">enabled</xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="printoptions">
      <xsl:with-param name="archoptions" select="$archoptions" />
      <xsl:with-param name="globaloptions" select="$globaloptions" />
      <xsl:with-param name="localoptions" select="$localoptions" />
      <xsl:with-param name="tag">exclude</xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="printoptions">
      <xsl:with-param name="archoptions" select="$archoptions" />
      <xsl:with-param name="globaloptions" select="$globaloptions" />
      <xsl:with-param name="localoptions" select="$localoptions" />
      <xsl:with-param name="tag">retries</xsl:with-param>
    </xsl:call-template>
    <xsl:call-template name="printoptions">
      <xsl:with-param name="archoptions" select="$archoptions" />
      <xsl:with-param name="globaloptions" select="$globaloptions" />
      <xsl:with-param name="localoptions" select="$localoptions" />
      <xsl:with-param name="tag">timeout</xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template name="printgpgkey">
    <xsl:param name="archgpgkey" />
    <xsl:param name="gpgkey" />
    <xsl:value-of select="$archgpgkey" />
    <xsl:choose>
      <xsl:when test="$archgpgkey=''">
        <xsl:text>gpgcheck=0
</xsl:text>
      </xsl:when>
      <xsl:when test="$archgpgkey">
        <xsl:text>gpgcheck=1
gpgkey=</xsl:text>
        <xsl:value-of select="$archgpgkey" />
        <xsl:text>
</xsl:text>
      </xsl:when>
      <xsl:when test="$gpgkey!=''">
        <xsl:text>gpgcheck=1
gpgkey=</xsl:text>
        <xsl:value-of select="$gpgkey" />
        <xsl:text>
</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>gpgcheck=0
</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="printlocations">
    <xsl:param name="archlocation" />
    <xsl:param name="location" />
    <xsl:choose>
      <xsl:when test="$archlocation[baseurl!='' or mirrorlist!='']">
        <xsl:for-each select="$archlocation/baseurl">
          <xsl:choose>
            <xsl:when test="position()=1">
              <xsl:text>baseurl=</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <xsl:text>  </xsl:text>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="." />
          <xsl:text>
</xsl:text>
        </xsl:for-each>
        <xsl:for-each select="$archlocation/mirrorlist">
          <xsl:choose>
            <xsl:when test="position()=1">
              <xsl:text>mirrorlist=</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <xsl:text>  </xsl:text>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="." />
          <xsl:text>
</xsl:text>
        </xsl:for-each>
      </xsl:when>
      <xsl:otherwise>
        <xsl:for-each select="$location[name()='baseurl']">
          <xsl:choose>
            <xsl:when test="position()=1">
              <xsl:text>baseurl=</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <xsl:text>  </xsl:text>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="." />
          <xsl:text>
</xsl:text>
        </xsl:for-each>
        <xsl:for-each select="$location[name()='mirrorlist']">
          <xsl:choose>
            <xsl:when test="position()=1">
              <xsl:text>mirrorlist=</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <xsl:text>  </xsl:text>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:value-of select="." />
          <xsl:text>
</xsl:text>
        </xsl:for-each>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="printoptions">
    <xsl:param name="archoptions" />
    <xsl:param name="globaloptions" />
    <xsl:param name="localoptions" />
    <xsl:param name="tag" />
    <xsl:choose>
      <xsl:when test="$archoptions/*[name()=$tag]">
        <xsl:value-of select="$tag" />
        <xsl:text>=</xsl:text>
        <xsl:value-of select="$archoptions/*[name()=$tag]" />
        <xsl:text>
</xsl:text>
      </xsl:when>
      <xsl:when test="$localoptions[name()=$tag]">
        <xsl:value-of select="$tag" />
        <xsl:text>=</xsl:text>
        <xsl:value-of select="$localoptions[name()=$tag]" />
        <xsl:text>
</xsl:text>
      </xsl:when>
      <xsl:when test="$globaloptions/*[name()=$tag]">
        <xsl:value-of select="$tag" />
        <xsl:text>=</xsl:text>
        <xsl:value-of select="$globaloptions/*[name()=$tag]" />
        <xsl:text>
</xsl:text>
      </xsl:when>
    </xsl:choose>
  </xsl:template>
</xsl:stylesheet>
